@@ -266,52 +266,52 @@ class Clusters(Base):
             )
         return response
 
-    @GigapipeApi.autorefresh_access_token
-    def autoscale_disk(self, cluster_slug: str, payload: Dict[str, Any]) -> Response:
-        """
-        Sets the disk autoscaling for a given disk and cluster
-        :param cluster_slug: the cluster slug
-        :param payload: the autoscale payload
-        :return: A message response
-        """
-        url: str = f"{self.api.url}/{self.api.__class__.version}/clusters/{cluster_slug}/disks/autoscale"
-
-        try:
-            response: Response = requests.patch(url, headers={
-                "Authorization": f"Bearer {self.api.access_token}"
-            }, json=payload)
-        except requests.RequestException as e:
-            raise GigapipeServerError(
-                status_code=HTTPStatus.INTERNAL_SERVER_ERROR,
-                message=f"Internal Server Error: {e}"
-            )
-        except TypeError:
-            raise GigapipeClientError(
-                status_code=HTTPStatus.BAD_REQUEST,
-                message=f"Wrong Payload"
-            )
-        return response
-
-    @GigapipeApi.autorefresh_access_token
-    def delete_autoscaling(self, cluster_slug: str, *, disk_id: int) -> Response:
-        """
-        Does away with the autoscaling for a given disk
-        :param disk_id: the id of the disk
-        :param cluster_slug: the cluster slug
-        :return: A message response
-        """
-        url: str = f"{self.api.url}/{self.api.__class__.version}/clusters/{cluster_slug}/disks/{disk_id}/autoscale"
-
-        try:
-            response: Response = requests.delete(url, headers={
-                "Authorization": f"Bearer {self.api.access_token}"
-            })
-        except requests.RequestException as e:
-            raise GigapipeServerError(
-                status_code=HTTPStatus.INTERNAL_SERVER_ERROR,
-                message=f"Internal Server Error: {e}"
-            )
-        return response
+    # @GigapipeApi.autorefresh_access_token
+    # def autoscale_disk(self, cluster_slug: str, payload: Dict[str, Any]) -> Response:
+    #     """
+    #     Sets the disk autoscaling for a given disk and cluster
+    #     :param cluster_slug: the cluster slug
+    #     :param payload: the autoscale payload
+    #     :return: A message response
+    #     """
+    #     url: str = f"{self.api.url}/{self.api.__class__.version}/clusters/{cluster_slug}/disks/autoscale"
+    #
+    #     try:
+    #         response: Response = requests.patch(url, headers={
+    #             "Authorization": f"Bearer {self.api.access_token}"
+    #         }, json=payload)
+    #     except requests.RequestException as e:
+    #         raise GigapipeServerError(
+    #             status_code=HTTPStatus.INTERNAL_SERVER_ERROR,
+    #             message=f"Internal Server Error: {e}"
+    #         )
+    #     except TypeError:
+    #         raise GigapipeClientError(
+    #             status_code=HTTPStatus.BAD_REQUEST,
+    #             message=f"Wrong Payload"
+    #         )
+    #     return response
+    #
+    # @GigapipeApi.autorefresh_access_token
+    # def delete_autoscaling(self, cluster_slug: str, *, disk_id: int) -> Response:
+    #     """
+    #     Does away with the autoscaling for a given disk
+    #     :param disk_id: the id of the disk
+    #     :param cluster_slug: the cluster slug
+    #     :return: A message response
+    #     """
+    #     url: str = f"{self.api.url}/{self.api.__class__.version}/clusters/{cluster_slug}/disks/{disk_id}/autoscale"
+    #
+    #     try:
+    #         response: Response = requests.delete(url, headers={
+    #             "Authorization": f"Bearer {self.api.access_token}"
+    #         })
+    #     except requests.RequestException as e:
+    #         raise GigapipeServerError(
+    #             status_code=HTTPStatus.INTERNAL_SERVER_ERROR,
+    #             message=f"Internal Server Error: {e}"
+    #         )
+    #     return response
 
     @GigapipeApi.autorefresh_access_token
     def expand_disk(self, cluster_slug: str, *, disk_id: int, payload: Dict[str, int]) -> Response:
